# GDI_effects
GDI_effects is a Python library that allows you to create GDI screen effects on Windows.

## Installation
First, you need to install the pywin32 library using pip:
```shell
pip install pywin32
```

After installing pywin32, you can install GDI_effects via pip:
```shell
pip install GDI-effects
```

## Usage
Below is an example of how to use the library to create various screen effects:
```python
from GDI_effects.GDI import *
Effects.type_text("Hello, world!", 100)
# Display "Hello, world!" at random positions on the screen.
# "Hello, world!" (str): The text to be displayed on the screen.
# 100 (int): The number of times the text is displayed on the screen.
```

## Available Functions
```python

Effects.bw_screen(repeat=200) # Creates a black and white effect on the screen.

Effects.copy_screen(repeat=200) # Continuously copies the entire screen area and displays it without any offset.

Effects.error_screen(repeat=200) # Displays error icons at various positions on the screen.

Effects.warning_screen(repeat=200) # Displays a warning icon randomly on the screen.

Effects.question_screen(repeat=200) # Displays a question icon randomly on the screen.

Effects.asterisk_screen(repeat=200) # Displays an asterisk icon randomly on the screen.

Effects.super_icon_screen(repeat=200) # displays various system icons randomly on the screen. 

Effects.invert_screen(repeat=200) # Inverts the colors on the screen.

Effects.pan_screen(repeat=200) # Pans the screen in random directions.

Effects.rainbow_blink(repeat=200) # Creates random rainbow effects on the screen.

Effects.screen_wavy(repeat=200) # Creates a wavy effect on the screen.

Effects.void_screen(repeat=200) # Creates a void effect on the screen.

Effects.glitch_screen(repeat=200) # Creates a glitch effect on the screen.

Effects.tunnel_screen(repeat=200) # Creates a tunnel effect by continuously stretching and copying the screen content inwards from the edges.

Effects.twisted_screen(repeat=200) # Apply a twisted screen effect by performing bitwise operations on the screen content.

Effects.rotate_screen(repeat=200) # Creates a rotation effect for the entire screen around a fixed radius.

Effects.repeat_block_rotation(repeat=200) # Creates a rotation effect for small blocks of the screen.

Effects.draw_random_scribble(repeat=200) # Drawing of random scribbles on the screen.

Effectstype_text(text, repeat=200) # Display text at random positions on the screen.

Effects.flip_screen_upside_down(repeat=200) # Continuously flip the computer screen upside down.
```
